.. _require_deb_module:

:mod:`fabtools.require.deb`
---------------------------

.. automodule:: fabtools.require.deb

    .. seealso:: :ref:`deb_module`

    Keys
    ~~~~

    .. autofunction:: key

    Sources
    ~~~~~~~

    .. autofunction:: source
    .. autofunction:: ppa

    Index
    ~~~~~

    .. autofunction:: uptodate_index

    Packages
    ~~~~~~~~

    .. autofunction:: package
    .. autofunction:: packages
    .. autofunction:: nopackage
    .. autofunction:: nopackages
